from paraview.simple import *

def generate_streamtracer_customsource(input_path, Source1, output_path ):
    # set source
    Source1 = FindSource(Source1)
    # create a new 'CSV Reader'
    out1 = CSVReader(FileName=[input_path])
    UpdatePipeline(proxy=out1)
    # create a new 'Table To Points'
    table_to_points1 = TableToPoints(Input=out1)
    # Properties modified on table_to_points1
    table_to_points1.XColumn = 'Points_0'
    table_to_points1.YColumn = 'Points_1'
    table_to_points1.ZColumn = 'Points_2'
    # Generate and parameterize StreamTracer
    stream_tracer = StreamTracerWithCustomSource(registrationName='StreamTracerWithCustomSource1', Input=Source1,
                                                     SeedSource=table_to_points1)

    stream_tracer.SurfaceStreamlines = True
    stream_tracer.Vectors = 'wallShearStress'
    stream_tracer.IntegrationDirection = 'BACKWARD'
    stream_tracer.IntegrationStepUnit = 'Cell Length'
    stream_tracer.MinimumStepLength = 0.2
    stream_tracer.MaximumStepLength = 0.8
    stream_tracer.MaximumError = 0.000001

    # Preparing StreamTracer Data Export
    Show(stream_tracer)
    SetActiveView(None)

    # Create a new 'SpreadSheet View'
    spreadSheetView2 = CreateView('SpreadSheetView')
    # get active source.
    StreamTracerWithCustomSource1 = GetActiveSource()

    # show data in view
    airfoil_v35foamDisplay = Show(StreamTracerWithCustomSource1, spreadSheetView2, 'SpreadSheetRepresentation')
    # export view
    ExportView(output_path, view=spreadSheetView2)

generalPath = '/home/philipp/Schreibtisch/domaintest/'
Path1 = generalPath + 'SeedPointsHigh.csv'

if __name__ == "__main__":
    generate_streamtracer_customsource(Path1, 'airfoil_smooth_v2_extruded.foam', generalPath + 'StreamTracerData1.csv')
